@@ -169,6 +169,10 @@ def kind_from_path(path: Path, *, base: bool = False) -> FileType:
     if str(path) == "/dev/stdin":
         return "playbook"
 
+    if "pattern.json" in str(path):
+        # This is a pattern file
+        return "pattern"
+
     # Unknown file types report a empty string (evaluated as False)
     return ""
 
@@ -183,7 +187,7 @@ class Lintable:
     When symlinks are given, they will always be resolved to their target.
     """
 
-    # pylint: disable=too-many-arguments
+    # pylint: disable=too-many-arguments,too-many-positional-arguments
     def __init__(
         self,
         name: str | Path,
@@ -239,7 +243,11 @@ class Lintable:
 
         if str(self.path) in ["/dev/stdin", "-"]:
             # pylint: disable=consider-using-with
-            self.file = NamedTemporaryFile(mode="w+", suffix="playbook.yml")
+            self.file = NamedTemporaryFile(  # noqa: SIM115
+                mode="w+",
+                suffix="playbook.yml",
+                encoding="utf-8",
+            )
             self.filename = self.file.name
             self._content = sys.stdin.read()
             self.file.write(self._content)
@@ -322,7 +330,7 @@ class Lintable:
         """Retrieve file content, from internal cache or disk."""
         if self._content is None:
             self._populate_content_cache_from_disk()
-        return cast(str, self._content)
+        return cast("str", self._content)
 
     @content.setter
     def content(self, value: str) -> None:
@@ -403,7 +411,8 @@ class Lintable:
     def failed(self) -> bool:
         """Return true if we already found syntax-check errors on this file."""
         return any(
-            match.rule.id in ("syntax-check", "load-failure") for match in self.matches
+            match.rule.id in ("syntax-check", "load-failure", "internal-error")
+            for match in self.matches
         )
 
     @property
@@ -431,12 +440,13 @@ class Lintable:
                         from ansiblelint.skip_utils import append_skipped_rules
 
                     # pylint: disable=possibly-used-before-assignment
-                    self.state = append_skipped_rules(
-                        self.state,
-                        self,
-                    )
+                    if self.state:
+                        self.state = append_skipped_rules(
+                            self.state,
+                            self,
+                        )
                 else:
-                    logging.debug(
+                    _logger.debug(
                         "data set to None for %s due to being '%s' (%s) kind.",
                         self.path,
                         self.kind,
@@ -474,11 +484,6 @@ def discover_lintables(options: Options) -> list[str]:
     ]
 
 
-def strip_dotslash_prefix(fname: str) -> str:
-    """Remove ./ leading from filenames."""
-    return fname[2:] if fname.startswith("./") else fname
-
-
 def find_project_root(
     srcs: Sequence[str],
     config_file: str | None = None,
@@ -585,6 +590,7 @@ def get_all_files(
         pathspecs = [
             pathspec.GitIgnoreSpec.from_lines(
                 [
+                    ".ansible",
                     ".git",
                     ".tox",
                     ".mypy_cache",
@@ -611,7 +617,7 @@ def get_all_files(
         else:
             for item in sorted(path.iterdir()):
                 if is_excluded(item):
-                    _logger.info("Excluded: %s", item)
+                    _logger.debug("Excluded: %s", item)
                     continue
                 if item.is_file():
                     all_files.append(item)
