@@ -26,7 +26,7 @@ from ansiblelint._internal.rules import (
 from ansiblelint.app import App, get_app
 from ansiblelint.config import PROFILES, Options
 from ansiblelint.config import options as default_options
-from ansiblelint.constants import LINE_NUMBER_KEY, RULE_DOC_URL, SKIPPED_RULES_KEY
+from ansiblelint.constants import RULE_DOC_URL, SKIPPED_RULES_KEY
 from ansiblelint.errors import MatchError
 from ansiblelint.file_utils import Lintable, expand_paths_vars
 
@@ -46,6 +46,9 @@ match_types = {
     "matchplay": "play",  # called by matchyaml
     "matchdir": "dir",
 }
+RE_JINJA_EXPRESSION = re.compile(r"{{.+?}}")
+RE_JINJA_STATEMENT = re.compile(r"{%.+?%}")
+RE_JINJA_COMMENT = re.compile(r"{#.+?#}")
 
 
 class AnsibleLintRule(BaseRule):
@@ -63,9 +66,9 @@ class AnsibleLintRule(BaseRule):
     @staticmethod
     def unjinja(text: str) -> str:
         """Remove jinja2 bits from a string."""
-        text = re.sub(r"{{.+?}}", "JINJA_EXPRESSION", text)
-        text = re.sub(r"{%.+?%}", "JINJA_STATEMENT", text)
-        text = re.sub(r"{#.+?#}", "JINJA_COMMENT", text)
+        text = RE_JINJA_EXPRESSION.sub("JINJA_EXPRESSION", text)
+        text = RE_JINJA_STATEMENT.sub("JINJA_STATEMENT", text)
+        text = RE_JINJA_COMMENT.sub("JINJA_COMMENT", text)
         return text
 
     # pylint: disable=too-many-arguments,too-many-positional-arguments
@@ -73,15 +76,22 @@ class AnsibleLintRule(BaseRule):
         self,
         message: str = "",
         lineno: int = 1,
+        column: int | None = None,
         details: str = "",
         filename: Lintable | None = None,
         tag: str = "",
         transform_meta: RuleMatchTransformMeta | None = None,
+        data: Any | None = None,
     ) -> MatchError:
         """Instantiate a new MatchError."""
+        if data is not None and lineno == 1 and column is None:
+            lineno, column = ansiblelint.yaml_utils.get_line_column(
+                data, default_line=lineno
+            )
         match = MatchError(
             message=message,
             lineno=lineno,
+            column=column,
             details=details,
             lintable=filename or Lintable(""),
             rule=copy.copy(self),
@@ -108,9 +118,9 @@ class AnsibleLintRule(BaseRule):
     ) -> None:
         match.task = task
         if not match.details:
-            match.details = "Task/Handler: " + ansiblelint.utils.task_to_str(task)
+            match.details = "Task/Handler: " + str(task)
 
-        match.lineno = max(match.lineno, task[LINE_NUMBER_KEY])
+        match.lineno = max(match.lineno, task.line)
 
     def matchlines(self, file: Lintable) -> list[MatchError]:
         matches: list[MatchError] = []
@@ -204,7 +214,7 @@ class AnsibleLintRule(BaseRule):
                     message = result
                 match = self.create_matcherror(
                     message=message,
-                    lineno=task.normalized_task[LINE_NUMBER_KEY],
+                    lineno=task.line,
                     filename=file,
                 )
 
@@ -224,7 +234,7 @@ class AnsibleLintRule(BaseRule):
         if isinstance(yaml, str):
             if yaml.startswith("$ANSIBLE_VAULT"):
                 return []
-            if self._collection is None:
+            if self._collection is None:  # pragma: no cover
                 msg = f"Rule {self.id} was not added to a collection."
                 raise RuntimeError(msg)
             return [
@@ -467,10 +477,6 @@ class RulesCollection:
         msg = f"Rule {item} is not present inside this collection."
         raise ValueError(msg)
 
-    def extend(self, more: list[AnsibleLintRule]) -> None:
-        """Combine rules."""
-        self.rules.extend(more)
-
     def run(
         self,
         file: Lintable,
@@ -525,12 +531,6 @@ class RulesCollection:
 
         return matches
 
-    def __repr__(self) -> str:
-        """Return a RulesCollection instance representation."""
-        return "\n".join(
-            [rule.verbose() for rule in sorted(self.rules, key=lambda x: x.id)],
-        )
-
     def known_tags(self) -> list[str]:
         """Return a list of known tags, without returning no sub-tags."""
         tags = set()
@@ -551,7 +551,7 @@ class RulesCollection:
             "idiom": "Anti-pattern detected, likely to cause undesired behavior",
             "metadata": "Invalid metadata, likely related to galaxy, collections or roles",
             "opt-in": "Rules that are not used unless manually added to `enable_list`",
-            "security": "Rules related o potentially security issues, like exposing credentials",
+            "security": "Rules related to potential security issues, like exposing credentials",
             "syntax": "Related to wrong or deprecated syntax",
             "unpredictability": "Warn about code that might not work in a predictable way",
             "unskippable": "Indicate a fatal error that cannot be ignored or disabled",
@@ -561,7 +561,7 @@ class RulesCollection:
         tags = defaultdict(list)
         for rule in self.rules:
             # Fail early if a rule does not have any of our required tags
-            if not set(rule.tags).intersection(tag_desc.keys()):
+            if not set(rule.tags).intersection(tag_desc.keys()):  # pragma: no cover
                 msg = f"Rule {rule} does not have any of the required tags: {', '.join(tag_desc.keys())}"
                 raise RuntimeError(msg)
             for tag in rule.tags:
