@@ -4,9 +4,12 @@ from __future__ import annotations
 
 import re
 import sys
+from collections.abc import MutableMapping
 from typing import TYPE_CHECKING, Any
 
-from ansiblelint.constants import LINE_NUMBER_KEY
+import wcmatch.pathlib
+import wcmatch.wcmatch
+
 from ansiblelint.file_utils import Lintable
 from ansiblelint.rules import AnsibleLintRule, TransformMixin
 
@@ -28,7 +31,7 @@ class NameRule(AnsibleLintRule, TransformMixin):
     )
     severity = "MEDIUM"
     tags = ["idiom"]
-    version_added = "v6.9.1 (last update)"
+    version_changed = "6.9.1"
     _re_templated_inside = re.compile(r".*\{\{.*\}\}.*\w.*$")
     _ids = {
         "name[play]": "All plays should be named.",
@@ -36,29 +39,83 @@ class NameRule(AnsibleLintRule, TransformMixin):
         "name[prefix]": "Task name should start with a prefix.",
         "name[casing]": "All names should start with an uppercase letter.",
         "name[template]": "Jinja templates should only be at the end of 'name'",
+        "name[unique]": "Task names should be unique within a play.",
     }
 
+    def _check_unique_task_names(
+        self,
+        tasks: list[MutableMapping[str, Any]],
+        seen_names: dict[str, int],
+        file: Lintable,
+    ) -> list[MatchError]:
+        """Helper function to iterate through a list of tasks and check for duplicates."""
+        errors: list[MatchError] = []
+        if not tasks:
+            return errors
+
+        for task in tasks:
+            # We skip tasks without a name, as that is covered by the 'name[missing]' rule.
+            task_name = task.get("name")
+            if not task_name:
+                continue
+
+            # If a task-like dict lacks a line number, we cannot perform the uniqueness check, so we skip it.
+            if "__line__" not in task:
+                continue
+
+            # The linter adds '__line__' to each task dictionary.
+            lineno = task["__line__"]
+
+            if task_name in seen_names:
+                message = f"Task name '{task_name}' is not unique. It was first used on line {seen_names[task_name]}."
+                errors.append(
+                    self.create_matcherror(
+                        message=message,
+                        lineno=lineno,
+                        filename=file,
+                        tag="name[unique]",
+                    )
+                )
+            else:
+                seen_names[task_name] = lineno
+        return errors
+
     def matchplay(self, file: Lintable, data: dict[str, Any]) -> list[MatchError]:
         """Return matches found for a specific play (entry in playbook)."""
-        results = []
+        results: list[MatchError] = []
         if file.kind != "playbook":
             return []
+        if file.failed():  # pragma: no cover
+            return results
+
+        # Check if the play itself is named
         if "name" not in data:
             return [
                 self.create_matcherror(
                     message="All plays should be named.",
-                    lineno=data[LINE_NUMBER_KEY],
                     tag="name[play]",
                     filename=file,
+                    data=data,
                 ),
             ]
         results.extend(
             self._check_name(
                 data["name"],
                 lintable=file,
-                lineno=data[LINE_NUMBER_KEY],
+                data=data,
             ),
         )
+
+        # Check for unique task names within this play
+        seen_task_names: dict[str, int] = {}
+        task_sections = ["pre_tasks", "tasks", "post_tasks", "handlers"]
+        for section in task_sections:
+            tasks = data.get(section, [])
+            if tasks:
+                results.extend(
+                    self._check_unique_task_names(tasks, seen_task_names, file)
+                )
+
         return results
 
     def matchtask(
@@ -66,13 +123,16 @@ class NameRule(AnsibleLintRule, TransformMixin):
         task: Task,
         file: Lintable | None = None,
     ) -> list[MatchError]:
-        results = []
+        """Check rules for a single task."""
+        results: list[MatchError] = []
+        if file and file.failed():  # pragma: no cover
+            return results
         name = task.get("name")
         if not name:
             results.append(
                 self.create_matcherror(
                     message="All tasks should be named.",
-                    lineno=task[LINE_NUMBER_KEY],
+                    lineno=task.line,
                     tag="name[missing]",
                     filename=file,
                 ),
@@ -82,9 +142,10 @@ class NameRule(AnsibleLintRule, TransformMixin):
                 self._prefix_check(
                     name,
                     lintable=file,
-                    lineno=task[LINE_NUMBER_KEY],
+                    lineno=task.line,
                 ),
             )
+
         return results
 
     def _prefix_check(
@@ -103,16 +164,13 @@ class NameRule(AnsibleLintRule, TransformMixin):
                 self._check_name(
                     effective_name,
                     lintable=lintable,
-                    lineno=lineno,
+                    data=lintable.data,
                 ),
             )
         return results
 
     def _check_name(
-        self,
-        name: str,
-        lintable: Lintable | None,
-        lineno: int,
+        self, name: str, lintable: Lintable | None, data: Any
     ) -> list[MatchError]:
         # This rules applies only to languages that do have uppercase and
         # lowercase letter, so we ignore anything else. On Unicode isupper()
@@ -121,10 +179,15 @@ class NameRule(AnsibleLintRule, TransformMixin):
         # stage one check prefix
         effective_name = name
         if self._collection and lintable:
-            prefix = self._collection.options.task_name_prefix.format(
-                stem=lintable.path.stem,
-            )
-            if lintable.kind == "tasks" and lintable.path.stem != "main":
+            full_stem = self._find_full_stem(lintable)
+            stems = [
+                self._collection.options.task_name_prefix.format(stem=stem)
+                for stem in wcmatch.pathlib.PurePath(
+                    full_stem,
+                ).parts
+            ]
+            prefix = "".join(stems)
+            if lintable.kind == "tasks" and full_stem != "main":
                 if not name.startswith(prefix):
                     # For the moment in order to raise errors this rule needs to be
                     # enabled manually. Still, we do allow use of prefixes even without
@@ -133,7 +196,7 @@ class NameRule(AnsibleLintRule, TransformMixin):
                         results.append(
                             self.create_matcherror(
                                 message=f"Task name should start with '{prefix}'.",
-                                lineno=lineno,
+                                data=data,
                                 tag="name[prefix]",
                                 filename=lintable,
                             ),
@@ -143,14 +206,15 @@ class NameRule(AnsibleLintRule, TransformMixin):
                     effective_name = name[len(prefix) :]
 
         if (
-            effective_name[0].isalpha()
+            effective_name
+            and effective_name[0].isalpha()
             and effective_name[0].islower()
             and not effective_name[0].isupper()
         ):
             results.append(
                 self.create_matcherror(
                     message="All names should start with an uppercase letter.",
-                    lineno=lineno,
+                    data=name,
                     tag="name[casing]",
                     filename=lintable,
                 ),
@@ -159,13 +223,45 @@ class NameRule(AnsibleLintRule, TransformMixin):
             results.append(
                 self.create_matcherror(
                     message="Jinja templates should only be at the end of 'name'",
-                    lineno=lineno,
+                    data=name,
                     tag="name[template]",
                     filename=lintable,
                 ),
             )
         return results
 
+    def _find_full_stem(self, lintable: Lintable) -> str:
+        lintable_dir = wcmatch.pathlib.PurePath(lintable.dir)
+        stem = lintable.path.stem
+        kind = str(lintable.kind)
+
+        stems = [lintable_dir.name]
+        lintable_dir = lintable_dir.parent
+        pathex = lintable_dir / stem
+        glob = ""
+
+        if self.options:
+            for entry in self.options.kinds:
+                for key, value in entry.items():
+                    if kind == key:
+                        glob = value
+
+        while pathex.globmatch(
+            glob,
+            flags=(
+                wcmatch.pathlib.GLOBSTAR
+                | wcmatch.pathlib.BRACE
+                | wcmatch.pathlib.DOTGLOB
+            ),
+        ):
+            stems.insert(0, lintable_dir.name)
+            lintable_dir = lintable_dir.parent
+            pathex = lintable_dir / stem
+
+        if stems and stems[0].startswith(kind):
+            del stems[0]
+        return str(wcmatch.pathlib.PurePath(*stems, stem))
+
     def transform(
         self,
         match: MatchError,
@@ -189,8 +285,13 @@ class NameRule(AnsibleLintRule, TransformMixin):
             if orig_task_name:
                 updated_task_name = update_task_name(orig_task_name)
                 for item in data:
-                    if isinstance(item, dict) and "tasks" in item:
+                    if isinstance(item, MutableMapping) and "tasks" in item:
                         for task in item["tasks"]:
+                            # We want to rewrite task names in the notify keyword, but
+                            # if there isn't a notify section, there's nothing to do.
+                            if "notify" not in task:
+                                continue
+
                             if (
                                 isinstance(task["notify"], str)
                                 and orig_task_name == task["notify"]
@@ -201,15 +302,6 @@ class NameRule(AnsibleLintRule, TransformMixin):
                                     if orig_task_name == task["notify"][idx]:
                                         task["notify"][idx] = updated_task_name
 
-                    if isinstance(item, dict) and "handlers" in item:
-                        for task in item["handlers"]:
-                            listener_task_name = task.get("listen", None)
-                            if (
-                                listener_task_name
-                                and listener_task_name == orig_task_name
-                            ):
-                                task["listen"] = updated_task_name
-
                 target_task["name"] = updated_task_name
                 match.fixed = True
 
@@ -224,7 +316,7 @@ if "pytest" in sys.modules:
         collection.register(NameRule())
         success = "examples/playbooks/rule-name-missing-pass.yml"
         good_runner = Runner(success, rules=collection)
-        assert [] == good_runner.run()
+        assert good_runner.run() == []
 
     def test_file_negative() -> None:
         """Negative test for name[missing]."""
@@ -235,6 +327,19 @@ if "pytest" in sys.modules:
         errs = bad_runner.run()
         assert len(errs) == 5
 
+    def test_name_prefix_positive(config_options: Options) -> None:
+        """Positive test for name[prefix]."""
+        config_options.enable_list = ["name[prefix]"]
+        collection = RulesCollection(options=config_options)
+        collection.register(NameRule())
+        success = Lintable(
+            "examples/playbooks/tasks/main.yml",
+            kind="tasks",
+        )
+        good_runner = Runner(success, rules=collection)
+        results = good_runner.run()
+        assert len(results) == 0
+
     def test_name_prefix_negative(config_options: Options) -> None:
         """Negative test for name[missing]."""
         config_options.enable_list = ["name[prefix]"]
@@ -252,6 +357,36 @@ if "pytest" in sys.modules:
         assert results[1].tag == "name[prefix]"
         assert results[2].tag == "name[prefix]"
 
+    def test_name_prefix_negative_2(config_options: Options) -> None:
+        """Negative test for name[prefix]."""
+        config_options.enable_list = ["name[prefix]"]
+        collection = RulesCollection(options=config_options)
+        collection.register(NameRule())
+        failure = Lintable(
+            "examples/playbooks/tasks/partial_prefix/foo.yml",
+            kind="tasks",
+        )
+        bad_runner = Runner(failure, rules=collection)
+        results = bad_runner.run()
+        assert len(results) == 2
+        assert results[0].tag == "name[prefix]"
+        assert results[1].tag == "name[prefix]"
+
+    def test_name_prefix_negative_3(config_options: Options) -> None:
+        """Negative test for name[prefix]."""
+        config_options.enable_list = ["name[prefix]"]
+        collection = RulesCollection(options=config_options)
+        collection.register(NameRule())
+        failure = Lintable(
+            "examples/playbooks/tasks/partial_prefix/main.yml",
+            kind="tasks",
+        )
+        bad_runner = Runner(failure, rules=collection)
+        results = bad_runner.run()
+        assert len(results) == 2
+        assert results[0].tag == "name[prefix]"
+        assert results[1].tag == "name[prefix]"
+
     def test_rule_name_lowercase() -> None:
         """Negative test for a task that starts with lowercase."""
         collection = RulesCollection()
