@@ -4,9 +4,9 @@ from __future__ import annotations
 
 import re
 import sys
+from collections.abc import MutableMapping
 from typing import TYPE_CHECKING, Any
 
-from ansiblelint.constants import LINE_NUMBER_KEY
 from ansiblelint.rules import AnsibleLintRule, TransformMixin
 
 if TYPE_CHECKING:
@@ -16,6 +16,8 @@ if TYPE_CHECKING:
     from ansiblelint.file_utils import Lintable
     from ansiblelint.utils import Task
 
+RE_JINJA = re.compile(r"{{ (.*?) }}")
+
 
 class NoFormattingInWhenRule(AnsibleLintRule, TransformMixin):
     """No Jinja2 in when."""
@@ -26,7 +28,7 @@ class NoFormattingInWhenRule(AnsibleLintRule, TransformMixin):
     )
     severity = "HIGH"
     tags = ["deprecations"]
-    version_added = "historic"
+    version_changed = "6.20.0"
 
     @staticmethod
     def _is_valid(when: str) -> bool:
@@ -52,7 +54,7 @@ class NoFormattingInWhenRule(AnsibleLintRule, TransformMixin):
                 self.create_matcherror(
                     details=str({"when": role}),
                     filename=file,
-                    lineno=role[LINE_NUMBER_KEY],
+                    data=role,
                 )
                 for role in data["roles"]
                 if (
@@ -80,12 +82,13 @@ class NoFormattingInWhenRule(AnsibleLintRule, TransformMixin):
             task = self.seek(match.yaml_path, data)
             key_to_check = ("when", "changed_when", "failed_when")
             for _ in range(len(task)):
-                k, v = task.popitem(False)
-                if k == "roles" and isinstance(v, list):
-                    transform_for_roles(v, key_to_check=key_to_check)
-                elif k in key_to_check:
-                    v = re.sub(r"{{ (.*?) }}", r"\1", v)
-                task[k] = v
+                if isinstance(task, MutableMapping):
+                    for k, v in task.items():
+                        if k == "roles" and isinstance(v, list):
+                            transform_for_roles(v, key_to_check=key_to_check)
+                        elif k in key_to_check:
+                            v = RE_JINJA.sub(r"\1", v)
+                            task[k] = v
             match.fixed = True
 
 
@@ -96,10 +99,10 @@ def transform_for_roles(v: list[Any], key_to_check: tuple[str, ...]) -> None:
             if new_key in key_to_check:
                 if isinstance(new_value, list):
                     for index, nested_value in enumerate(new_value):
-                        new_value[index] = re.sub(r"{{ (.*?) }}", r"\1", nested_value)
+                        new_value[index] = RE_JINJA.sub(r"\1", nested_value)
                     v[idx][new_key] = new_value
                 if isinstance(new_value, str):
-                    v[idx][new_key] = re.sub(r"{{ (.*?) }}", r"\1", new_value)
+                    v[idx][new_key] = RE_JINJA.sub(r"\1", new_value)
 
 
 if "pytest" in sys.modules:
@@ -113,7 +116,7 @@ if "pytest" in sys.modules:
         collection.register(NoFormattingInWhenRule())
         success = "examples/playbooks/rule-no-jinja-when-pass.yml"
         good_runner = Runner(success, rules=collection)
-        assert [] == good_runner.run()
+        assert good_runner.run() == []
 
     def test_jinja_file_negative() -> None:
         """Negative test for no-jinja-when."""
