@@ -38,13 +38,12 @@ class OctalPermissionsRule(AnsibleLintRule):
 
     id = "risky-octal"
     description = (
-        "Numeric file permissions without leading zero can behave "
-        "in unexpected ways."
+        "Numeric file permissions without leading zero can behave in unexpected ways."
     )
     link = "https://docs.ansible.com/ansible/latest/collections/ansible/builtin/file_module.html"
     severity = "VERY_HIGH"
     tags = ["formatting"]
-    version_added = "historic"
+    version_changed = "6.9.1"
 
     _modules = [
         "assemble",
