@@ -7,13 +7,11 @@ import re
 import sys
 from typing import TYPE_CHECKING, Any, NamedTuple
 
-from ansible.parsing.yaml.objects import AnsibleUnicode
 from ansible.vars.reserved import get_reserved_names
 
 from ansiblelint.config import Options, options
 from ansiblelint.constants import (
     ANNOTATION_KEYS,
-    LINE_NUMBER_KEY,
     PLAYBOOK_ROLE_KEYWORDS,
     RC,
 )
@@ -137,6 +135,7 @@ class VariableNamingRule(AnsibleLintRule):
                 tag="var-naming[non-ascii]",
                 message=f"Variables names must be ASCII. ({ident})",
                 filename=file,
+                data=ident,
             )
 
         if keyword.iskeyword(ident):
@@ -144,6 +143,7 @@ class VariableNamingRule(AnsibleLintRule):
                 tag="var-naming[no-keyword]",
                 message=f"Variables names must not be Python keywords. ({ident})",
                 filename=file,
+                data=ident,
             )
 
         if ident in self.reserved_names:
@@ -151,6 +151,7 @@ class VariableNamingRule(AnsibleLintRule):
                 tag="var-naming[no-reserved]",
                 message=f"Variables names must not be Ansible reserved names. ({ident})",
                 filename=file,
+                data=ident,
             )
 
         if ident in self.read_only_names:
@@ -158,6 +159,7 @@ class VariableNamingRule(AnsibleLintRule):
                 tag="var-naming[read-only]",
                 message=f"This special variable is read-only. ({ident})",
                 filename=file,
+                data=ident,
             )
 
         # We want to allow use of jinja2 templating for variable names
@@ -171,6 +173,7 @@ class VariableNamingRule(AnsibleLintRule):
                 tag="var-naming[pattern]",
                 message=f"Variables names should match {self.re_pattern_str} regex. ({ident})",
                 filename=file,
+                data=ident,
             )
 
         if (
@@ -183,6 +186,7 @@ class VariableNamingRule(AnsibleLintRule):
                 tag="var-naming[no-role-prefix]",
                 message=f"Variables names from within roles should use {prefix.value}_ as a prefix.",
                 filename=file,
+                data=ident,
             )
         return None
 
@@ -198,32 +202,20 @@ class VariableNamingRule(AnsibleLintRule):
         for key in our_vars:
             match_error = self.get_var_naming_matcherror(key, file=file)
             if match_error:
-                match_error.lineno = (
-                    key.ansible_pos[1]
-                    if isinstance(key, AnsibleUnicode)
-                    else our_vars[LINE_NUMBER_KEY]
-                )
                 raw_results.append(match_error)
         roles = data.get("roles", [])
         for role in roles:
-            if isinstance(role, AnsibleUnicode):
+            if isinstance(role, str):
                 continue
             role_fqcn = role.get("role", role.get("name"))
             prefix = self._parse_prefix(role_fqcn)
             for key in list(role.keys()):
                 if key not in PLAYBOOK_ROLE_KEYWORDS:
                     match_error = self.get_var_naming_matcherror(
-                        key,
-                        prefix=prefix,
-                        file=file,
+                        key, prefix=prefix, file=file
                     )
                     if match_error:
                         match_error.message += f" (vars: {key})"
-                        match_error.lineno = (
-                            key.ansible_pos[1]
-                            if isinstance(key, AnsibleUnicode)
-                            else role[LINE_NUMBER_KEY]
-                        )
                         raw_results.append(match_error)
 
             our_vars = role.get("vars", {})
@@ -235,11 +227,6 @@ class VariableNamingRule(AnsibleLintRule):
                 )
                 if match_error:
                     match_error.message += f" (vars: {key})"
-                    match_error.lineno = (
-                        key.ansible_pos[1]
-                        if isinstance(key, AnsibleUnicode)
-                        else our_vars[LINE_NUMBER_KEY]
-                    )
                     raw_results.append(match_error)
         if raw_results:
             lines = file.content.splitlines()
@@ -261,27 +248,26 @@ class VariableNamingRule(AnsibleLintRule):
     ) -> list[MatchError]:
         """Return matches for task based variables."""
         results = []
-        prefix = Prefix()
+        task_prefix = Prefix()
+        role_prefix = Prefix()
         if file and file.parent and file.parent.kind == "role":
-            prefix = Prefix(file.parent.path.name)
+            role_prefix = Prefix(file.parent.path.name)
         ansible_module = task["action"]["__ansible_module__"]
         # If the task uses the 'vars' section to set variables
+        # only check role prefix for include_role and import_role tasks 'vars'
         our_vars = task.get("vars", {})
         if ansible_module in ("include_role", "import_role"):
             action = task["action"]
             if isinstance(action, dict):
                 role_fqcn = action.get("name", "")
-                prefix = self._parse_prefix(role_fqcn)
-        else:
-            prefix = Prefix()
+                task_prefix = self._parse_prefix(role_fqcn)
         for key in our_vars:
             match_error = self.get_var_naming_matcherror(
                 key,
-                prefix=prefix,
+                prefix=task_prefix,
                 file=file or Lintable(""),
             )
             if match_error:
-                match_error.lineno = our_vars[LINE_NUMBER_KEY]
                 match_error.message += f" (vars: {key})"
                 results.append(match_error)
 
@@ -295,11 +281,11 @@ class VariableNamingRule(AnsibleLintRule):
             ):
                 match_error = self.get_var_naming_matcherror(
                     key,
-                    prefix=prefix,
+                    prefix=role_prefix,
                     file=file or Lintable(""),
                 )
                 if match_error:
-                    match_error.lineno = task["action"][LINE_NUMBER_KEY]
+                    match_error.lineno = task.line
                     match_error.message += f" (set_fact: {key})"
                     results.append(match_error)
 
@@ -308,12 +294,12 @@ class VariableNamingRule(AnsibleLintRule):
         if registered_var:
             match_error = self.get_var_naming_matcherror(
                 registered_var,
-                prefix=prefix,
+                prefix=role_prefix,
                 file=file or Lintable(""),
             )
             if match_error:
                 match_error.message += f" (register: {registered_var})"
-                match_error.lineno = task[LINE_NUMBER_KEY]
+                match_error.lineno = task.line
                 results.append(match_error)
 
         return results
@@ -336,7 +322,6 @@ class VariableNamingRule(AnsibleLintRule):
                     file=file,
                 )
                 if match_error:
-                    match_error.lineno = key.ansible_pos[1]
                     match_error.message += f" (vars: {key})"
                     raw_results.append(match_error)
             if raw_results:
@@ -445,6 +430,7 @@ if "pytest" in sys.modules:
         for result in results:
             assert result.tag == "var-naming[no-role-prefix]"
 
+    @pytest.mark.libyaml
     def test_var_naming_with_role_prefix_plays(
         default_rules_collection: RulesCollection,
     ) -> None:
@@ -509,3 +495,24 @@ if "pytest" in sys.modules:
         result = run_ansible_lint(role_path)
         assert result.returncode == RC.SUCCESS
         assert "var-naming" not in result.stdout
+
+    def test_var_naming_register_set_fact_in_roles(
+        default_rules_collection: RulesCollection,
+    ) -> None:
+        """Test register and set_fact variable naming in roles."""
+        results = Runner(
+            Lintable("examples/roles/var_naming_no_role_prefix/tasks/main.yml"),
+            rules=default_rules_collection,
+        ).run()
+        expected_errors = [
+            ("var-naming[no-role-prefix]", "register: bad_register_var"),
+            ("var-naming[no-role-prefix]", "set_fact: bad_set_fact_var"),
+            ("var-naming[no-role-prefix]", "vars: bad_included_var"),
+            ("var-naming[no-role-prefix]", "vars: bad_imported_var"),
+        ]
+        # Filter only var-naming errors
+        # var_naming_errors = [r for r in results if r.rule.id == "var-naming"]
+        assert len(results) == len(expected_errors)
+        for idx, result in enumerate(results):
+            assert result.tag == expected_errors[idx][0]
+            assert expected_errors[idx][1] in result.message
