@@ -50,7 +50,9 @@ if TYPE_CHECKING:
     from collections.abc import Generator
 
     from ansiblelint.file_utils import Lintable
-    from ansiblelint.types import AnsibleBaseYAMLObject
+    from ansiblelint.types import (
+        AnsibleBaseYAMLObject,  # pyright: ignore[reportAttributeAccessIssue]
+    )
 
 
 _logger = logging.getLogger(__name__)
@@ -95,7 +97,7 @@ def get_rule_skips_from_line(
     return result
 
 
-def append_skipped_rules(
+def append_skipped_rules(  # type: ignore[no-any-unimported]
     pyyaml_data: AnsibleBaseYAMLObject,
     lintable: Lintable,
 ) -> AnsibleBaseYAMLObject:
@@ -143,7 +145,7 @@ def load_data(file_text: str) -> Any:
         return yaml.load_all(file_text)
 
 
-def _append_skipped_rules(
+def _append_skipped_rules(  # type: ignore[no-any-unimported]
     pyyaml_data: AnsibleBaseYAMLObject,
     lintable: Lintable,
 ) -> AnsibleBaseYAMLObject | None:
